<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>ID Code</title>
</head>
<body>
<main>
    <p>
        Your consent request verification code is {{code}}.
        Please return to the consent request page and enter the code to
        continue. This code will expire in {{minutes}} minutes
    </p>
</main>
</body>
</html>
